else-bug
--------
This directory was created in response to a bug in the code generation of
else statements - specifically in the code generation of statements using
identifiers. The reason for this was due to lack of propogation of context.

This directory was created to test/check this. I'm leaving it here to allow
testing for regression. It also acts as a simple example of how pyxie programs
can be written, compiled etc.
